@@ -28,6 +28,7 @@ from ..utils.people.to_database import (
     load_person,
     CancelTransaction,
 )
+from ..utils.people.merge import process_scrape_dir, incoming_merge
 
 
 OPTIONAL_FIELD_SET = {
@@ -287,7 +288,7 @@ def _echo_org_status(org: typing.Any, created: bool, updated: bool) -> None:
 
 def load_directory_to_database(files: list[Path], purge: bool) -> None:
     from openstates.data.models import Person as DjangoPerson
-    from openstates.data.models import BillSponsorship, PersonVote
+    from openstates.data.models import BillSponsorship, PersonVote, Jurisdiction
 
     ids = set()
     merged = {}
@@ -296,6 +297,7 @@ def load_directory_to_database(files: list[Path], purge: bool) -> None:
 
     all_data = []
     all_jurisdictions = []
+    updated_jurisdictions = set()
     for filename in files:
         person: Person = Person.load_yaml(filename)
         all_data.append((person, filename))
@@ -319,6 +321,9 @@ def load_directory_to_database(files: list[Path], purge: bool) -> None:
             click.secho(f"updated person from {filename}", fg="cyan")
             updated_count += 1
 
+        if created or updated:
+            updated_jurisdictions.add(person.roles[0].jurisdiction)
+
     missing_ids = existing_ids - ids
 
     # check if missing ids are in need of a merge
@@ -353,6 +358,11 @@ def load_directory_to_database(files: list[Path], purge: bool) -> None:
         click.secho(f"{len(missing_ids)} purged", fg="yellow")
         DjangoPerson.objects.filter(id__in=missing_ids).delete()
 
+    if created_count or updated_count:
+        Jurisdiction.objects.filter(id__in=updated_jurisdictions).update(
+            latest_people_update=datetime.datetime.utcnow()
+        )
+
     click.secho(
         f"processed {len(ids)} person files, {created_count} created, "
         f"{updated_count} updated",
@@ -672,6 +682,7 @@ def to_database(abbreviations: list[str], purge: bool, safe: bool) -> None:
         try:
             with transaction.atomic():
                 load_directory_to_database(person_files, purge=purge)
+
                 if safe:
                     click.secho("ran in safe mode, no changes were made", fg="magenta")
                     raise CancelTransaction()
@@ -679,5 +690,37 @@ def to_database(abbreviations: list[str], purge: bool, safe: bool) -> None:
             sys.exit(1)
 
 
+@main.command()  # pragma: no cover
+@click.argument("abbr")
+@click.argument("input_dir")
+@click.option(
+    "--retirement",
+    default=None,
+    help="Set retirement date for all people marked retired.",
+)
+def merge(abbr: str, input_dir: str, retirement: str) -> None:
+    """
+    Convert scraped JSON in INPUT_DIR to YAML files for this repo.
+    """
+    jurisdiction_id = abbr_to_jid(abbr)
+
+    new_people = process_scrape_dir(Path(input_dir), jurisdiction_id)
+
+    existing_people: list[Person] = []
+    directory = get_data_path(abbr)
+    for filename in itertools.chain(
+        directory.glob("legislature/*.yml"),
+        directory.glob("retired/*.yml"),
+    ):
+        existing_people.append(Person.load_yaml(filename))
+
+    click.secho(
+        f"analyzing {len(existing_people)} existing people and {len(new_people)} scraped"
+    )
+
+    unmatched = incoming_merge(abbr, existing_people, new_people, retirement)
+    click.secho(f"{len(unmatched)} people were unmatched")
+
+
 if __name__ == "__main__":
     main()
