@@ -1,6 +1,7 @@
 from collections import OrderedDict
 import argparse
 import contextlib
+import datetime
 import glob
 import importlib
 import logging
@@ -97,24 +98,30 @@ def do_import(juris, args):
         JurisdictionImporter,
         BillImporter,
         VoteEventImporter,
+        EventImporter,
     )
+    from openstates.data.models import Jurisdiction as DatabaseJurisdiction
 
     datadir = os.path.join(settings.SCRAPED_DATA_DIR, args.module)
 
     juris_importer = JurisdictionImporter(juris.jurisdiction_id)
     bill_importer = BillImporter(juris.jurisdiction_id)
     vote_event_importer = VoteEventImporter(juris.jurisdiction_id, bill_importer)
+    event_importer = EventImporter(juris.jurisdiction_id, vote_event_importer)
     report = {}
 
     with transaction.atomic():
         print("import jurisdictions...")
         report.update(juris_importer.import_directory(datadir))
-        if settings.ENABLE_BILLS:
-            print("import bills...")
-            report.update(bill_importer.import_directory(datadir))
-        if settings.ENABLE_VOTES:
-            print("import vote events...")
-            report.update(vote_event_importer.import_directory(datadir))
+        print("import bills...")
+        report.update(bill_importer.import_directory(datadir))
+        print("import vote events...")
+        report.update(vote_event_importer.import_directory(datadir))
+        print("import events...")
+        report.update(event_importer.import_directory(datadir))
+        DatabaseJurisdiction.objects.filter(id=juris.jurisdiction_id).update(
+            latest_bill_update=datetime.datetime.utcnow()
+        )
 
     # compile info on all sessions that were updated in this run
     seen_sessions = set()
