@@ -33,14 +33,16 @@ from .event import (
     Event,
     EventLocation,
     EventMedia,
-    EventMediaLink,
     EventDocument,
-    EventLink,
-    EventSource,
     EventParticipant,
     EventAgendaItem,
     EventRelatedEntity,
     EventAgendaMedia,
-    EventAgendaMediaLink,
-    EventDocumentLink,
+)
+from .reports import (
+    RunPlan,
+    ScrapeReport,
+    ScrapeObjects,
+    ImportObjects,
+    SessionDataQualityReport,
 )
