@@ -1,3 +1,4 @@
+import datetime
 from django.db import models
 from ..common import JURISDICTION_CLASSIFICATION_CHOICES, SESSION_CLASSIFICATION_CHOICES
 from .base import OCDBase, OCDIDField, RelatedBase
@@ -37,6 +38,8 @@ class Jurisdiction(OCDBase):
         # don't allow deletion of a division that a Jurisdiction depends upon
         on_delete=models.PROTECT,
     )
+    latest_bill_update = models.DateTimeField(default=datetime.date(2021, 1, 1))
+    latest_people_update = models.DateTimeField(default=datetime.date(2021, 1, 1))
 
     class Meta:
         db_table = "opencivicdata_jurisdiction"
