@@ -1,49 +1,37 @@
 from .base import BaseImporter
 from ._types import _JsonDict
-from ..utils import get_pseudo_id, _make_pseudo_id
+from ..utils import get_pseudo_id
 from ..data.models import (
     Event,
     EventLocation,
-    EventSource,
     EventDocument,
-    EventDocumentLink,
-    EventLink,
     EventParticipant,
     EventMedia,
-    EventMediaLink,
     EventAgendaItem,
     EventRelatedEntity,
     EventAgendaMedia,
-    EventAgendaMediaLink,
 )
 from .organizations import OrganizationImporter
 from .vote_events import VoteEventImporter
-from .bills import BillImporter
 
 
 class EventImporter(BaseImporter):
     _type = "event"
     model_class = Event
     related_models = {
-        "sources": (EventSource, "event_id", {}),
         "documents": (
             EventDocument,
             "event_id",
-            {"links": (EventDocumentLink, "document_id", {})},
+            {},
         ),
-        "links": (EventLink, "event_id", {}),
         "participants": (EventParticipant, "event_id", {}),
-        "media": (EventMedia, "event_id", {"links": (EventMediaLink, "media_id", {})}),
+        "media": (EventMedia, "event_id", {}),
         "agenda": (
             EventAgendaItem,
             "event_id",
             {
                 "related_entities": (EventRelatedEntity, "agenda_item_id", {}),
-                "media": (
-                    EventAgendaMedia,
-                    "agenda_item_id",
-                    {"links": (EventAgendaMediaLink, "media_id", {})},
-                ),
+                "media": (EventAgendaMedia, "agenda_item_id", {}),
             },
         ),
     }
@@ -52,13 +40,10 @@ class EventImporter(BaseImporter):
     def __init__(
         self,
         jurisdiction_id: str,
-        org_importer: OrganizationImporter,
-        bill_importer: BillImporter,
         vote_event_importer: VoteEventImporter,
     ):
         super(EventImporter, self).__init__(jurisdiction_id)
-        self.org_importer = org_importer
-        self.bill_importer = bill_importer
+        self.org_importer = OrganizationImporter(jurisdiction_id)
         self.vote_event_importer = vote_event_importer
 
     def get_object(self, event: _JsonDict) -> Event:
@@ -83,17 +68,24 @@ class EventImporter(BaseImporter):
             url=location_data.get("url", ""),
             jurisdiction_id=self.jurisdiction_id,
         )
-        # TODO: geocode here?
         return obj
 
     def prepare_for_db(self, data: _JsonDict) -> _JsonDict:
         data["jurisdiction_id"] = self.jurisdiction_id
         data["location"] = self.get_location(data["location"])
 
+        # all objects being inserted should be non-deleted
+        data["deleted"] = False
         data["start_date"] = data["start_date"]
         data["end_date"] = data.get("end_date", "")
 
         for participant in data["participants"]:
+            # conversion from old/incorrect names first
+            if "committee_id" in participant:
+                participant["organization_id"] = participant.pop("committee_id")
+            if "legislator_id" in participant:
+                participant["person_id"] = participant.pop("legislator_id")
+
             if "person_id" in participant:
                 participant["person_id"] = self.resolve_person(participant["person_id"])
             elif "organization_id" in participant:
@@ -110,12 +102,9 @@ class EventImporter(BaseImporter):
                         entity["organization_id"], allow_no_match=True
                     )
                 elif "bill_id" in entity:
-                    # unpack and repack bill psuedo id in case filters alter it
                     bill = get_pseudo_id(entity["bill_id"])
-                    self.bill_importer.apply_transformers(bill)
-                    bill = _make_pseudo_id(**bill)
-                    entity["bill_id"] = self.bill_importer.resolve_json_id(
-                        bill, allow_no_match=True
+                    entity["bill_id"] = self.resolve_bill(
+                        bill["identifier"], date=data["start_date"]
                     )
                 elif "vote_event_id" in entity:
                     entity["vote_event_id"] = self.vote_event_importer.resolve_json_id(
@@ -123,3 +112,10 @@ class EventImporter(BaseImporter):
                     )
 
         return data
+
+    def postimport(self) -> None:
+        all_db_ids = self.json_to_db_id.values()
+        update_set = Event.objects.filter(jurisdiction_id=self.jurisdiction_id).exclude(
+            id__in=all_db_ids, deleted=False
+        )
+        update_set.update(deleted=True)
