@@ -3,5 +3,6 @@ from .jurisdiction import Jurisdiction, JurisdictionScraper
 from .popolo import Membership, Organization, Person, Post
 from .vote_event import VoteEvent
 from .bill import Bill
-from .event import Event
+from .event import Event, calculate_window
 from .base import Scraper, BaseBillScraper
+from ..exceptions import EmptyScrape
