@@ -41,6 +41,6 @@ schema = {
         },
         "sources": sources,
         "extras": extras,
-        "pupa_id": {"type": ["string", "null"], "minLength": 1},
+        "dedupe_key": {"type": ["string", "null"], "minLength": 1},
     },
 }
